KSTAR is an open-source software for estimating kinase activities from phosphoproteomic data.
KSTAR implements statistical and graph-theoretic approaches to produce a robust activity score that 
increases with increasing evidence from a kinase’s network.

Documentation at https://naeglelab.github.io/KSTAR/index.html
